#define MALLOC_ERROR -1

#include <stdlib.h>
#include <stdio.h>
#include <geany.h>
#include <ui_utils.h>
#include <plugindata.h>
#include <editor.h>
#include <document.h>
#include <geanyfunctions.h>
#include <Scintilla.h>
#include <libxml/parser.h>
#include <libxml/tree.h>

GeanyPlugin     *geany_plugin;
GeanyData       *geany_data;
GeanyFunctions  *geany_functions;

PLUGIN_VERSION_CHECK(130)

PLUGIN_SET_INFO("XML Formatter", "Format an XML file",
                "1.0", "Cédric Tabin - http://www.astorm.ch");

static GtkWidget *main_menu_item = NULL;

static void item_activate_cb(GtkMenuItem *menuitem, gpointer gdata)
{
	//retrieves the current document
	GeanyDocument* doc = document_get_current();
	GeanyEditor* editor = doc->editor;
	ScintillaObject* sco = editor->sci;

	//allocate a new pointer
	int length = sci_get_length(sco)+1;
	char* buffer = (char*)malloc(length*sizeof(char));
	if (buffer == NULL) { exit(MALLOC_ERROR); } //malloc error
	
	//retrieves the text
	sci_get_text(sco, length, buffer);
	
	//checks if the data is an XML format
	xmlDoc* xmlDoc = xmlParseDoc((unsigned char*)buffer);
	
	if(xmlDoc == NULL)
	{
		dialogs_show_msgbox(GTK_MESSAGE_ERROR, "Unable to parse the content as XML.");
		return;
	}

	xmlFreeDoc(xmlDoc);
}

void plugin_init(GeanyData *data)
{
    //Initializes the libxml2
    LIBXML_TEST_VERSION

    //put the menu into the Tools
    main_menu_item = gtk_menu_item_new_with_mnemonic("XML Formatter");
    gtk_widget_show(main_menu_item);
    gtk_container_add(GTK_CONTAINER(geany->main_widgets->tools_menu),
        main_menu_item);

    //add activation callback
    g_signal_connect(main_menu_item, "activate",
        G_CALLBACK(item_activate_cb), NULL);
}

void plugin_cleanup(void)
{
    //destroys the plugin
    gtk_widget_destroy(main_menu_item);
}
